@@ -158,7 +158,7 @@ asn1_octet_der (const unsigned char *str, int str_len,
 {
   int len_len;
 
-  if (der == NULL || str_len <= 0)
+  if (der == NULL || str_len < 0)
     return;
   asn1_length_der (str_len, der, &len_len);
   memcpy (der + len_len, str, str_len);
@@ -913,7 +913,8 @@ asn1_der_coding (ASN1_TYPE element, const char *name, void *ider, int *len,
 	case TYPE_NULL:
 	  max_len--;
 	  if (max_len >= 0)
-	    der[counter++] = 0;
+	    der[counter] = 0;
+	  counter++;
 	  move = RIGHT;
 	  break;
 	case TYPE_BOOLEAN:
